@@ -43,7 +43,6 @@ use serde::{Deserialize, Serialize};
 use std::{
     fs::{self, File},
     io::Write,
-    path::Path,
     path::PathBuf,
     str,
     time::SystemTime,
@@ -52,14 +51,14 @@ use tiny_http::{Response, Server};
 
 ///Exposes all of the API functions for the [MyAnimeList API](https://myanimelist.net/apiconfig/references/api/v2)
 ///
-///**With the exception of all the manga-related funcitons which haven't been implemented yet**
+///**With the exception of all the manga-related functions which haven't been implemented yet**
 ///
 ///# Example
 ///```rust
 /// use lib_mal::MALClient;
 /// # async fn main() {
 /// let client = MALClient::new([YOUR_SECRET_HERE]).await;
-/// //--do authorization stuff before accessing the funcitons--//
+/// //--do authorization stuff before accessing the functions--//
 ///
 /// //Gets the details with all fields for Mobile Suit Gundam
 /// let anime = client.get_anime_details(80, None).await.expect("Couldn't get anime details");
@@ -81,7 +80,7 @@ pub struct MALClient {
 
 impl MALClient {
     ///Creates the client and fetches the MAL tokens from the cache if available. If `caching` is
-    ///fasle or `cache_dir` is `None` the user will have to log in at the start of every session.
+    ///false or `cache_dir` is `None` the user will have to log in at the start of every session.
     ///
     ///When created client will attempt to refresh the access_token if it has expired
     pub async fn new(secret: &str, caching: bool, cache_dir: Option<PathBuf>) -> Self {
@@ -226,7 +225,7 @@ impl MALClient {
             break;
         }
 
-        self.get_tokens(&code, &challenge).await
+        self.get_tokens(&code, challenge).await
     }
 
     async fn get_tokens(&mut self, code: &str, verifier: &str) -> Result<(), String> {
@@ -332,7 +331,7 @@ impl MALClient {
         self.parse_response(&res)
     }
 
-    ///Gets the deatils for an anime by the show's ID.
+    ///Gets the details for an anime by the show's ID.
     ///Only returns the fields specified in the `fields` parameter
     ///
     ///Returns all fields when supplied `None`
@@ -427,12 +426,10 @@ impl MALClient {
         let params = update.get_params();
         let url = format!("https://api.myanimelist.net/v2/anime/{}/my_list_status", id);
         let res = self.do_request_forms(url, params).await?;
-        println!("{}", res);
         self.parse_response(&res)
     }
 
     ///Returns the user's full anime list as an `AnimeList` struct.
-    ///If the request fails for any reason, an `Err` object with a string describing the error is returned instead
     pub async fn get_user_anime_list(&self) -> Result<AnimeList, String> {
         let url = "https://api.myanimelist.net/v2/users/@me/animelist?fields=list_status&limit=4";
         let res = self.do_request(url.to_owned()).await?;
@@ -473,6 +470,7 @@ impl MALClient {
         self.parse_response(&res)
     }
 
+    ///Returns details of the specified topic
     pub async fn get_forum_topic_detail(
         &self,
         topic_id: u32,
@@ -487,6 +485,7 @@ impl MALClient {
         self.parse_response(&res)
     }
 
+    ///Returns all topics for a given query
     pub async fn get_forum_topics(
         &self,
         board_id: Option<u32>,
@@ -536,7 +535,7 @@ impl MALClient {
 
 fn encrypt_token(toks: Tokens) -> Result<Vec<u8>, ()> {
     let key = Key::from_slice(b"one two three four five six seve");
-    let cypher = Aes256Gcm::new(&key);
+    let cypher = Aes256Gcm::new(key);
     let nonce = Nonce::from_slice(b"but the eart");
     let plain = serde_json::to_vec(&toks).unwrap();
     let res = cypher.encrypt(nonce, plain.as_ref()).unwrap();
@@ -545,7 +544,7 @@ fn encrypt_token(toks: Tokens) -> Result<Vec<u8>, ()> {
 
 fn decrypt_tokens(raw: &[u8]) -> Result<Tokens, ()> {
     let key = Key::from_slice(b"one two three four five six seve");
-    let cypher = Aes256Gcm::new(&key);
+    let cypher = Aes256Gcm::new(key);
     let nonce = Nonce::from_slice(b"but the eart");
     let plain = cypher
         .decrypt(nonce, raw.as_ref())
